program read_ita
!
!  Convert International Transactions Accounts files from BEA's 
!  format to numerical matrices.  
!
!  Users need to edit this file to include the specific input file
!  (e.g., Table6a.csv) in the open file and the table number.
!
!  Ellen McGrattan, 2-29-08
!
   implicit none
   integer               :: status,i,j,l,n,ifound1,ifound2,icom
   character (len=4)     :: tabnum
   character (len=2000)  :: c2000

   !
   ! Fill in the number for the table as a 4-character string (with 
   ! blanks at the end if necessary) and the file in the open statement
   !
   tabnum = '6b  '
   open(unit=5, file='ita/Table6b.csv')

 
   !
   ! Open the output files
   !
   open(unit=10,file='tableA.dat')
   open(unit=11,file='tableQ.dat')
   open(unit=20,file='tableA.doc')
   open(unit=21,file='tableQ.doc')

   !
   ! Read the BEA .csv file until annual table is found
   !
   ifound1 = 0
   n       = len_trim(tabnum)
   do while (ifound1==0)
     read(5,'(a)',iostat=status) c2000
     if (status < 0) exit
     if ( ((c2000(1:7)==',Table ').and.(c2000(8:7+n)==tabnum(1:n))).or.       &
          ((c2000(1:8)==',"Table ').and.(c2000(9:8+n)==tabnum(1:n))))  then
       write(20,'(a)') c2000(1:40)
       !
       ! Continue down the file until the years are given
       !
       ifound2 = 0
       do while (ifound2==0)
         read(5,'(a)',iostat=status) c2000
         if (status < 0) exit
         if (c2000(1:4)=='Line') then
           ifound2 = 1
           ifound1 = 1
           l       = len_trim(c2000)
           !
           ! Write dates to output file
           !
           do i=5,l
             if (((c2000(i:i)=='1').or.(c2000(i:i)=='2').or.                  &
                  (c2000(i:i)=='3').or.(c2000(i:i)=='4').or.                  &
                  (c2000(i:i)=='5').or.(c2000(i:i)=='6').or.                  &
                  (c2000(i:i)=='7').or.(c2000(i:i)=='8').or.                  &
                  (c2000(i:i)=='9').or.(c2000(i:i)=='0')).and.                &
                  (c2000(i-1:i-1)/='/')) then
               write(10,'(a)',advance='no') c2000(i:i)
             else
               write(10,'(a)',advance='no') ' '
             endif
           enddo
           write(10,'(a)',advance='yes') ' '
         else
           write(20,'(a)') c2000(1:40)
         endif
       enddo
     endif
   enddo

   !
   ! Read in annual series and write them out cleanly to a new file
   !
   ifound1 = 0
   do while (ifound1==0)
     read(5,'(a)',iostat=status) c2000
     if (status < 0) exit
     l      = len_trim(c2000)
     !
     ! Lines with data will start with an integer
     ! (as will some of the footnote lines)
     !
     if ((c2000(1:1)=='1').or.(c2000(1:1)=='2').or.                     &
         (c2000(1:1)=='3').or.(c2000(1:1)=='4').or.                     &
         (c2000(1:1)=='5').or.(c2000(1:1)=='6').or.                     &
         (c2000(1:1)=='7').or.(c2000(1:1)=='8').or.                     &
         (c2000(1:1)=='9') ) then
        i      = 1
        !
        ! Count 2 commas separating line #, description, and variable name
        !
        icom   = 0
        do while (icom<1)
          write(20,'(a)',advance='no') c2000(i:i)
          if (c2000(i:i)==',') icom=icom+1
          i = i+1
        enddo
        !
        ! Sometimes a description contains a comma but will appear in quotes
        !
        if (c2000(i:i)=='"') then
          i = i+1
          do while (c2000(i:i)/='"')
            write(20,'(a)',advance='no') c2000(i:i)
            i = i+1
          enddo
        endif
        !
        ! Continue counting the commas
        !
        do while (icom<2)
          write(20,'(a)',advance='no') c2000(i:i)
          if (c2000(i:i)==',') icom=icom+1
          i = i+1
        enddo
        write(20,'(a)') ' '
        !
        ! Write out series in output file
        !
        call writeout(10,10,'tableA.dat',l-i+1,c2000(i:l))
     endif
     if (c2000(1:16)==',"Table Creation') ifound1 = 1
   enddo
   write(20,'(a)') ' '

   !
   ! Read quarterly table next
   !
   ifound1 = 0
   do while (ifound1==0)
     read(5,'(a)',iostat=status) c2000
     if (status < 0) exit
     if ( ((c2000(1:7)==',Table ').and.(c2000(8:7+n)==tabnum(1:n))).or.       &
          ((c2000(1:8)==',"Table ').and.(c2000(9:8+n)==tabnum(1:n))))  then
       write(21,'(a)') c2000(1:40)
       !
       ! Continue down the file until the years:quarters
       !
       ifound2 = 0
       do while (ifound2==0)
         read(5,'(a)',iostat=status) c2000
         if (status < 0) exit
         if (c2000(1:4)=='Line') then
           ifound2 = 1
           ifound1 = 1
           l       = len_trim(c2000)
           !
           ! Write dates to output file
           !
           do i=5,l
             if (((c2000(i:i)=='1').or.(c2000(i:i)=='2').or.                  &
                  (c2000(i:i)=='3').or.(c2000(i:i)=='4').or.                  &
                  (c2000(i:i)=='5').or.(c2000(i:i)=='6').or.                  &
                  (c2000(i:i)=='7').or.(c2000(i:i)=='8').or.                  &
                  (c2000(i:i)=='9').or.(c2000(i:i)=='0')).and.                &
                  (c2000(i-1:i-1)/='/')) then
               write(11,'(a)',advance='no') c2000(i:i)
             endif
             if (c2000(i:i)==',') write(11,'(a)',advance='no') ' '
             if (c2000(i:i)==':') write(11,'(a)',advance='no') '.'
             if ((c2000(i-1:i)==':I').and.(i<l-1) ) then
                if (c2000(i:i+2)=='III') then
                  write(11,'(a)',advance='no') '3'
                elseif (c2000(i:i+1)=='IV') then
                  write(11,'(a)',advance='no') '4'
                elseif ((c2000(i:i+1)=='II').and.(c2000(i+2:i+2)/='I')) then
                  write(11,'(a)',advance='no') '2'
                else
                  write(11,'(a)',advance='no') '1'
                endif
             elseif ((c2000(i-1:i)==':I').and.(i==l-1) ) then
                if (c2000(i:i+1)=='II') then
                  write(11,'(a)',advance='no') '2'
                elseif (c2000(i:i+1)=='IV') then
                  write(11,'(a)',advance='no') '4'
                else
                  write(11,'(a)',advance='no') '1'
                endif
             elseif ((c2000(i-1:i)==':I').and.(i==l) ) then
               write(11,'(a)',advance='no') '1'
             endif
           enddo
           write(11,'(a)',advance='yes') ' '
         else
           write(21,'(a)') c2000(1:40)
         endif
       enddo
     endif
   enddo
   write(21,'(a)') ' '

   !
   ! Read in quarterly series and write them out cleanly to a new file
   !
   ifound1 = 0
   do while (ifound1==0)
     read(5,'(a)',iostat=status) c2000
     if (status < 0) exit
     l      = len_trim(c2000)
     !
     ! Lines with data will start with an integer
     ! (as will some of the footnote lines)
     !
     if ((c2000(1:1)=='1').or.(c2000(1:1)=='2').or.                     &
         (c2000(1:1)=='3').or.(c2000(1:1)=='4').or.                     &
         (c2000(1:1)=='5').or.(c2000(1:1)=='6').or.                     &
         (c2000(1:1)=='7').or.(c2000(1:1)=='8').or.                     &
         (c2000(1:1)=='9') ) then
        i      = 1
        !
        ! Count 3 commas separating line #, description, and variable name
        !
        icom   = 0
        do while (icom<1)
          write(21,'(a)',advance='no') c2000(i:i)
          if (c2000(i:i)==',') icom=icom+1
          i = i+1
        enddo
        !
        ! Sometimes a description contains a comma but will appear in quotes
        !
        if (c2000(i:i)=='"') then
          i = i+1
          do while (c2000(i:i)/='"')
            write(21,'(a)',advance='no') c2000(i:i)
            i = i+1
          enddo
        endif
        !
        ! Continue counting the commas
        !
        do while (icom<2)
          write(21,'(a)',advance='no') c2000(i:i)
          if (c2000(i:i)==',') icom=icom+1
          i = i+1
        enddo
        write(21,'(a)') ' '
        !
        ! Write out series in output file
        !
        call writeout(11,10,'tableQ.dat',l-i+1,c2000(i:l))
     endif
     if ((c2000(1:16)==',"Table Creation').or.                                &
         (c2000(1:9)=='Footnotes')) ifound1 = 1
   enddo

contains

function len_trim(string) result(len_trim_result)
!
!  Compute the length of a the substring that includes all characters
!  up to and including the last nonblank character.
!
   character(len = *), intent(in)    :: string
   integer                           :: len_trim_result, k
                                                                                
   len_trim_result = 0
   do k = len(string), 1, -1
      !
      ! or until nonblank found
      !
      if (string(k:k) /= " ") then
         len_trim_result = k
         exit
      end if
   end do

end function len_trim

subroutine writeout(iunit,lf,filestr,l,string)
!
!  Write out series of numbers that are comma deliminated. They may 
!  have quotes around them if they are larger than 1,000 and may 
!  have missing values with periods, eg., 
!
!    910.0,/15/984.6,"1,038.5",.....,"1,127.1","1,238.3",(*)
!
!  would be written out to iunit without quotes, commas, or footnotes
!  and with a Not-a-Number symbol replacing periods, n.a.'s, or (*):
!
!    910.0 984.6 1038.5 NaN 1127.1 1238.3 1382.7 NaN
!
!

   integer, intent(in)             :: iunit,lf,l
   character (len=l), intent(in)   :: string
   character (len=lf), intent(in)  :: filestr

   open(unit=iunit, file=filestr(1:lf))

   !
   ! Some lines have missing variables or footnotes in the first period
   !
   i  = 1
   if ((string(1:2)=='..').or.(string(1:2)=='n.').or.(string(1:2)=='(*')) then
     write(iunit,'(a)',advance='no') 'NaN'
     i = 3
     do while (string(i:i)/=',')
       i = i+1
     enddo
   elseif (string(1:1)=='/') then
     i = 2
     do while (string(i:i)/='/')
       i = i+1
     enddo
     i = i+1
     if (string(i:i)==',') write(iunit,'(a)',advance='no') 'NaN'
   endif
   !
   ! Clean up the remainder of the line 
   !
   do while (i<=l)
     if (string(i:i)==',') then
       !
       ! Replace missing observations with NaN
       !
       write(iunit,'(a)',advance='no') ' '
       i = i+1
       if ((i<l).and.((string(i:i+1)=='..').or.(string(i:i+1)=='n.').or.      &
           (string(i:i+1)=='(*'))) then
         write(iunit,'(a)',advance='no') 'NaN'
         i = i+2
         do while ((i<=l).and.(string(i:i)/=','))
           i = i+1
         enddo
       endif
     elseif (string(i:i)=='"') then
       !
       ! Remove quotes and eliminate commas in numbers over 1000
       !
       i = i+1
       do while ((i<=l).and.(string(i:i)/='"'))
         if ((i<=l).and.(string(i:i)/=',')) then
           write(iunit,'(a)',advance='no') string(i:i)
         endif
         i = i+1
       enddo
       write(iunit,'(a)',advance='no') ' '
       i = i+1
     elseif (string(i:i)=='/') then
       !
       ! Remove footnotes
       !
       i = i+1
       do while ((i<=l).and.(string(i:i)/='/'))
         i = i+1
       enddo
       i = i+1
       if (string(i:i)==',') write(iunit,'(a)',advance='no') 'NaN'
     else
       !
       ! If not a comma or quote, write the number
       !
       write(iunit,'(a)',advance='no') string(i:i)
       i = i+1
     endif 
   enddo
   write(iunit,'(a)') ' '

end subroutine writeout

end program read_ita

