%STD_STEADY  computes the steady state for the model without
%            technology capital.
%

%            Ellen McGrattan, 9-1-07
%            Revised, ERM, 1-17-08

alpha = .3;
beta  = .96;
delta = .05;
lam   = .78974;
psi   = 2.;
Au    = 1;
Ar    = .396;
Zu    = Au^(1/(1-alpha));
Zr    = Ar^(1/(1-alpha));
Nu    = 1;
Nr    = 8;
param = [alpha;beta;delta;lam;psi;Au;Ar;Nu;Nr];
kap   = beta*alpha/(1-beta*(1-delta));

%
% Initial guesses
%

Ku0   = 1.6049;
Kr0   = 3.4182;
Hu0   = .35*Nu;   
Hr0   = .35*Nr;   
X0    = [Ku0;Kr0;Hu0;Hr0];
%
% Solution
%
X     = secant('stdss',X0,param);
Ku    = X(1);
Kr    = X(2);
Hu    = X(3);
Hr    = X(4);
Xu    = delta*Ku;
Xr    = delta*Kr;
Yu    = Au*Ku^alpha*Hu^(1-alpha);
Yr    = Ar*Kr^alpha*Hr^(1-alpha);
Cu    = (Yu+Yr-Xu-Xr)/(1+(1-lam)*Nr/(lam*Nu));
Cr    = (1-lam)*Cu*Nr/(lam*Nu);
GDPu  = Yu;
GDPr  = Yr;
NXu   = GDPu-Cu-Xu;
NXr   = GDPr-Cr-Xr;
hu    = Hu/Nu;
hr    = Hr/Nr;

Du    = (1-delta*kap)*Yr-Cr;
Dr    = (1-delta*kap)*Yu-Cu;

